@@ -1,6 +1,6 @@
 # pylint: disable=C0103
 '''
-This module contains V/Hz control for induction motor drives.
+V/Hz control for induction motor drives.
 
 The method is similar to [1]_. Open-loop V/Hz control can be obtained as a
 special case by choosing::
@@ -27,7 +27,7 @@ from collections.abc import Callable
 from dataclasses import dataclass, field
 import numpy as np
 
-from motulator.control.common import PWM, RateLimiter, Delay, Datalogger
+from motulator.control.common import PWM, RateLimiter
 from motulator.helpers import abc2complex, Bunch
 
 
@@ -44,7 +44,6 @@ class InductionMotorVHzCtrlPars:
         repr=False, default=lambda t: (t > .2)*(2*np.pi*50))
     sensorless: bool = field(repr=False, default=True)  # Always sensorless
     T_s: float = 250e-6
-    delay: int = 1
     psi_s_nom: float = 1.04  # 1 p.u.
     rate_limit: float = 2*np.pi*120
     # Motor parameter estimates
@@ -57,7 +56,7 @@ class InductionMotorVHzCtrlPars:
 
 
 # %%
-class InductionMotorVHzCtrl(Datalogger):
+class InductionMotorVHzCtrl:
     """
     V/Hz control with the stator current feedback.
 
@@ -70,7 +69,6 @@ class InductionMotorVHzCtrl(Datalogger):
 
     # pylint: disable=too-many-instance-attributes
     def __init__(self, pars):
-        super().__init__()
         self.t = 0
         self.T_s = pars.T_s
         self.w_m_ref = pars.w_m_ref
@@ -78,7 +76,6 @@ class InductionMotorVHzCtrl(Datalogger):
         # Instantiate classes
         self.pwm = PWM(pars)
         self.rate_limiter = RateLimiter(pars)
-        self.delay = Delay(pars.delay)
         # Parameters
         self.k_u = pars.k_u
         self.k_w = pars.k_w
@@ -94,6 +91,7 @@ class InductionMotorVHzCtrl(Datalogger):
         self.i_s_ref = 0j
         self.theta_s = 0
         self.w_r_ref = 0
+        self.data = Bunch()
         self.desc = pars.__repr__()
 
     def __call__(self, mdl):
@@ -141,7 +139,7 @@ class InductionMotorVHzCtrl(Datalogger):
         data = Bunch(i_s_ref=self.i_s_ref, i_s=i_s, u_s=u_s, w_m_ref=w_m_ref,
                      w_r=w_r, w_s=w_s, psi_s_ref=self.psi_s_ref,
                      theta_s=self.theta_s, u_dc=u_dc, t=self.t)
-        self.save(data)
+        self._save(data)
 
         # Update the states
         self.i_s_ref += self.T_s*self.alpha_i*(i_s - self.i_s_ref)
@@ -189,5 +187,17 @@ class InductionMotorVHzCtrl(Datalogger):
                    + k*(self.i_s_ref - i_s))
         return u_s_ref
 
+    def _save(self, data):
+        for key, value in data.items():
+            self.data.setdefault(key, []).extend([value])
+
+    def post_process(self):
+        """
+        Transform the lists to the ndarray format.
+
+        """
+        for key in self.data:
+            self.data[key] = np.asarray(self.data[key])
+
     def __repr__(self):
         return self.desc
