@@ -1,6 +1,6 @@
 # pylint: disable=C0103
 """
-This module contains vector control for synchronous motor drives.
+Vector control for synchronous motor drives.
 
 """
 from __future__ import annotations
@@ -9,7 +9,7 @@ from dataclasses import dataclass, field
 import numpy as np
 
 from motulator.helpers import abc2complex, Bunch
-from motulator.control.common import SpeedCtrl, PWM, Datalogger, Delay
+from motulator.control.common import SpeedCtrl, PWM
 from motulator.control.sm_torque import TorqueCharacteristics
 
 
@@ -28,7 +28,6 @@ class SynchronousMotorVectorCtrlPars:
     sensorless: bool = True
     # Sampling period
     T_s: float = 250e-6
-    delay: int = 1
     # Bandwidths
     alpha_c: float = 2*np.pi*200
     alpha_fw: float = 2*np.pi*20
@@ -83,7 +82,8 @@ class SynchronousMotorVectorCtrlPars:
         # tq.plot_flux_loci(self.i_s_max, base)
 
 
-class SynchronousMotorVectorCtrl(Datalogger):
+# %%
+class SynchronousMotorVectorCtrl:
     """
     Vector control for a synchronous motor drive.
 
@@ -100,7 +100,6 @@ class SynchronousMotorVectorCtrl(Datalogger):
             Control parameters.
 
         """
-        super().__init__()
         self.t = 0
         self.T_s = pars.T_s
         self.w_m_ref = pars.w_m_ref
@@ -111,11 +110,11 @@ class SynchronousMotorVectorCtrl(Datalogger):
         self.current_ref = CurrentRef(pars)
         self.observer = SensorlessObserver(pars)
         self.pwm = PWM(pars)
-        self.delay = Delay(pars.delay)
         if pars.sensorless:
             self.observer = SensorlessObserver(pars)
         else:
             self.observer = None
+        self.data = Bunch()
         self.desc = pars.__repr__()
 
     def __call__(self, mdl):
@@ -171,7 +170,7 @@ class SynchronousMotorVectorCtrl(Datalogger):
         data = Bunch(i_s_ref=i_s_ref, i_s=i_s, u_s=u_s, psi_s=psi_s,
                      w_m_ref=w_m_ref, w_m=w_m, theta_m=theta_m,
                      u_dc=u_dc, tau_M=tau_M, t=self.t)
-        self.save(data)
+        self._save(data)
 
         # Update states
         if self.sensorless:
@@ -184,6 +183,18 @@ class SynchronousMotorVectorCtrl(Datalogger):
 
         return self.T_s, d_abc_ref
 
+    def _save(self, data):
+        for key, value in data.items():
+            self.data.setdefault(key, []).extend([value])
+
+    def post_process(self):
+        """
+        Transform the lists to the ndarray format.
+
+        """
+        for key in self.data:
+            self.data[key] = np.asarray(self.data[key])
+
     def __repr__(self):
         return self.desc
 
